==> zio-aws-wafv2_2.13-5.17.104.12-sources.jar: zio/aws/wafv2/model/RateBasedStatementAggregateKeyType.scala <==
package zio.aws.wafv2.model
import scala.jdk.CollectionConverters._
sealed trait RateBasedStatementAggregateKeyType {
  def unwrap: software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType
}
object RateBasedStatementAggregateKeyType {
  def wrap(
      value: software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType
  ): zio.aws.wafv2.model.RateBasedStatementAggregateKeyType = value match {
    case software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.IP =>
      val r = IP
      r
    case software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.FORWARDED_IP =>
      val r = FORWARDED_IP
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.wafv2.model.RateBasedStatementAggregateKeyType {
    override def unwrap
        : software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType =
      software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.UNKNOWN_TO_SDK_VERSION
  }
  case object IP
      extends zio.aws.wafv2.model.RateBasedStatementAggregateKeyType {
    override def unwrap
        : software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType =
      software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.IP
  }
  case object FORWARDED_IP
      extends zio.aws.wafv2.model.RateBasedStatementAggregateKeyType {
    override def unwrap
        : software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType =
      software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.FORWARDED_IP
  }
}

==> zio-aws-wafv2_2.13-7.21.15.5-sources.jar: zio/aws/wafv2/model/RateBasedStatementAggregateKeyType.scala <==
package zio.aws.wafv2.model
import scala.jdk.CollectionConverters._
sealed trait RateBasedStatementAggregateKeyType {
  def unwrap: software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType
}
object RateBasedStatementAggregateKeyType {
  def wrap(
      value: software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType
  ): zio.aws.wafv2.model.RateBasedStatementAggregateKeyType = value match {
    case software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.IP =>
      val r = IP
      r
    case software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.FORWARDED_IP =>
      val r = FORWARDED_IP
      r
    case software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.CUSTOM_KEYS =>
      val r = CUSTOM_KEYS
      r
    case software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.CONSTANT =>
      val r = CONSTANT
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.wafv2.model.RateBasedStatementAggregateKeyType {
    override def unwrap
        : software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType =
      software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.UNKNOWN_TO_SDK_VERSION
  }
  case object IP
      extends zio.aws.wafv2.model.RateBasedStatementAggregateKeyType {
    override def unwrap
        : software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType =
      software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.IP
  }
  case object FORWARDED_IP
      extends zio.aws.wafv2.model.RateBasedStatementAggregateKeyType {
    override def unwrap
        : software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType =
      software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.FORWARDED_IP
  }
  case object CUSTOM_KEYS
      extends zio.aws.wafv2.model.RateBasedStatementAggregateKeyType {
    override def unwrap
        : software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType =
      software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.CUSTOM_KEYS
  }
  case object CONSTANT
      extends zio.aws.wafv2.model.RateBasedStatementAggregateKeyType {
    override def unwrap
        : software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType =
      software.amazon.awssdk.services.wafv2.model.RateBasedStatementAggregateKeyType.CONSTANT
  }
}
